<?php

return[
    'project_modules' => [
        'pages' => [
            'paypal_module' => [
                'label' => 'PayPal',
                'position' => 100,
                'file' => __DIR__ . '/../docs/paypal.md',
            ],
        ],
    ],
];
